@@ -1,4 +1,4 @@
-/* $MirOS: contrib/code/jupp/selinux.c,v 1.6 2012/11/10 16:22:20 tg Exp $ */
+/* $MirOS: contrib/code/jupp/selinux.c,v 1.7 2014/06/26 18:15:17 tg Exp $ */
 
 #include "config.h"
 #if defined(HAVE_SELINUX_HDR) && defined(HAVE_SELINUX_FUN)
@@ -152,7 +152,7 @@ output_security_context(char *from_file)
 		 */
 		if (errno == EOPNOTSUPP)
 			return 0;
-		
+
 		warn("Could not get security context for %s",
 		      from_file);
 		return 1;
@@ -163,34 +163,3 @@ output_security_context(char *from_file)
 #endif
 	return 0;
 }
-
-#if 0
-
-/*
-  Test program compile using the following command
-  cc -o t t.c -DWITH_SELINUX -DTEST -lselinux
- */
-
-#include <stdio.h>
-#include <stdlib.h>
-main(int argc, char **argv)
-{
-
-	printf("%d: %s\n", argc, argv[1]);
-	if (argc == 3) {
-		copy_security_context(argv[1], argv[2]);
-		output_security_context(argv[2]);
-	}
-	if (argc == 2) {
-		FILE *fd;
-		char *temp;
-		match_default_security_context(argv[1]);
-		mkstemp(temp);
-		printf("temp=%s", temp);
-		fd = fopen(temp, "w");
-		fclose(fd);
-		output_security_context(temp);
-		reset_default_security_context();
-	}
-}
-#endif
