@@ -1,4 +1,4 @@
-/* $MirOS: contrib/code/jupp/types.h,v 1.12 2013/08/19 18:25:44 tg Exp $ */
+/* $MirOS: contrib/code/jupp/types.h,v 1.14 2014/10/23 15:30:52 tg Exp $ */
 
 #ifndef _JOE_TYPES_H
 #define _JOE_TYPES_H
@@ -12,12 +12,16 @@
 #include <sys/types.h>				/* we need pid_t */
 #endif
 
+/* from mksh */
 #if defined(DEBUG) || defined(__COVERITY__)
-#define mkssert(e)	((e) ? (void)0 : exit(255))
+#define mkssert(e)	do { if (!(e)) exit(255); } while (/* CONSTCOND */ 0)
 #else
-#define mkssert(e)	((void)0)
+#define mkssert(e)	do { } while (/* CONSTCOND */ 0)
 #endif
 
+/* from mksh */
+#define NELEM(a)	(sizeof(a) / sizeof((a)[0]))
+
 #define LINK(type) struct { type *next; type *prev; }
 
 #define KEYS		256
